﻿
*3.1Correlation.
*Graphs > Legacy dialogs > Scatter/dot > Simple scatter.
GRAPH
  /SCATTERPLOT(BIVAR)=SBP WITH DBP
  /MISSING=LISTWISE.
*Analyze > Correlate > Bivariate .
CORRELATIONS
  /VARIABLES=SBP DBP
  /PRINT=TWOTAIL NOSIG
  /MISSING=PAIRWISE.

*3.2b Simple linear regression.
*Analyze > Regression > Linear.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT SBP
  /METHOD=ENTER DBP.

*3.3 Model assumptions
*Step 1. Obtain normality plots of the residuals.
DATASET ACTIVATE DataSet3.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT SBP
  /METHOD=ENTER DBP
  /RESIDUALS HISTOGRAM(ZRESID) NORMPROB(ZRESID).
*Step 2: save the predicted values and the unstandardized residuals. 
*Analyze > Regression > Linear > Save
Go to the ‘Save’ menu of the linear regression model and tick the box unstandardized predicted values and unstandardized residuals. 
*In the variable view and data view you will find two new variables: PRE_1 and RES_1.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT SBP
  /METHOD=ENTER DBP
  /SAVE PRED RESID.
*Step 3 plot the residuals against the covariate.
*Graphs > Legacy dialogs > Scatter/dot > Simple scatter.
*You can also use the chart builder: Graphs > Chart builder.
GRAPH
  /SCATTERPLOT(BIVAR)=DBP WITH RES_1
  /MISSING=LISTWISE.
*You can easily change the syntax to make the second plot:.
GRAPH
  /SCATTERPLOT(BIVAR)=PRE_1 WITH RES_1
  /MISSING=LISTWISE.

*3.4 Categorical variable codings.
*Step 1. BMI category.
DO IF MISSING(BMI).
COMPUTE BMI_cat=999999.
ELSE IF BMI <18.5.
COMPUTE BMI_cat=2.
ELSE IF BMI>=18.5 AND BMI<=25.
COMPUTE BMI_cat=1.
ELSE IF BMI>25.
COMPUTE BMI_cat=3.
END IF.
EXECUTE.
VARIABLE LABELS BMI_cat 'category of BMI'.
VALUE LABELS BMI_cat 1 'normal weight' 2 'underweight'  3 'overweight' 999999 'missing'.
*Step 2:
Make dummy variables.
RECODE BMI_cat (2=1) (ELSE=0) INTO BMI_dummy_1.
EXECUTE.
RECODE BMI_cat (3=1) (ELSE=0) INTO BMI_dummy_2.
EXECUTE.

*step 3 regression model with categorical variables.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT SBP
  /METHOD=ENTER BMI_dummy_1 BMI_dummy_2
  /SAVE PRED RESID.

*Option 2 (advanced) : via general linear model. Select main effects model and use the 'simple' contrast with the first level as reference.
*Menu: Analyze > General Linear Model > Univariate
*Use systolic blood pressure as dependent variable and BMI_cat as fixed factor. SPSS will create dummy variable automatically by going to Contrast 
Choose ‘simple’ contrast with the first category being the reference and click on change and continue
Go to Model. Choose a custom model and insert BMI_cat to the model field.

UNIANOVA SBP BY BMI_cat 
  /CONTRAST(BMI_cat)=Simple(1) 
  /METHOD=SSTYPE(3) 
  /INTERCEPT=INCLUDE 
  /CRITERIA=ALPHA(.05) 
  /DESIGN=BMI_cat.

*3.5.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT SBP
  /METHOD=ENTER sex age BMI current_smoker DBP.

*3.6
Step 1: select patients with non-missings on all included variables. 
USE ALL.
COMPUTE filter_$=(MISSING(IMT) ~= 1 AND MISSING(sex)  ~=  1 AND MISSING(age) ~= 1 AND 
    MISSING(psocase) ~= 1 AND MISSING(BMI) ~= 1 AND MISSING(Hypertension) ~= 1 AND 
    MISSING(current_smoker)~= 1 AND MISSING(Cholesterol) ~= 1).
VARIABLE LABELS filter_$ 'MISSING(IMT) ~= 1 AND MISSING(sex)  ~=  1 AND MISSING(age) ~= 1 AND '+
    'MISSING(psocase) ~= 1 AND MISSING(BMI) ~= 1 AND MISSING(Hypertension) ~= 1 AND '+
    'MISSING(current_smoker)~= 1 AND MISSING(Cholesterol) ~= 1 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.
*3.6a. A priori selection of confounders. 
*Univariable model.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT IMT
  /METHOD=ENTER psocase.
*Age and sex adjusted  model.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT IMT
  /METHOD=ENTER psocase age sex.
*Full multivariable model.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT IMT
  /METHOD=ENTER psocase age sex BMI Cholesterol current_smoker Hypertension.

*3.6b. Screen all potential confounders for the influence on the risk estimate for the exposure (psoriasis is the exposure)
*Change the syntax by changing BMI in the last line into Cholesterol, current_smoker and Hypertension.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT IMT
  /METHOD=ENTER psocase age sex BMI.
*3.6b Full multivariable model based on the previous step. 
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT IMT
  /METHOD=ENTER psocase age sex cholesterol hypertension.

*3.7 Interaction
Step 2: compute a new variable.
COMPUTE age_psocase=age*psocase.
EXECUTE.
*step 3 perform the regression.
REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT IMT
  /METHOD=ENTER psocase age sex cholesterol hypertension age_psocase.

FILTER OFF.
USE ALL.
EXECUTE.

* 3.8 Curve Estimation.
TSET NEWVAR=NONE.
CURVEFIT
  /VARIABLES=IMT WITH age
  /CONSTANT
  /MODEL=LINEAR QUADRATIC 
  /PRINT ANOVA
  /PLOT FIT.





