﻿*6.2
Analyze > Survival > Cox Regression.
COXREG survtime
  /STATUS=status(1)
  /PATTERN BY sex
  /CONTRAST (sex)=Indicator(1)
  /METHOD=ENTER sex 
  /PLOT LML
  /SAVE=PRESID
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).
*6.2 Step 3. 
*Test the PH assumption using Schoenfeld residuals. 
USE ALL.
COMPUTE filter_$=(status=1).
VARIABLE LABELS filter_$ 'status=1 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

RANK VARIABLES=survtime (A)
  /RANK
  /PRINT=YES
  /TIES=MEAN.

CORRELATIONS
  /VARIABLES=Rsurvtim PR1_1
  /PRINT=TWOTAIL NOSIG
  /MISSING=PAIRWISE.

FILTER OFF.
USE ALL.
EXECUTE.

*Step 4. Use time-dependent covariate to test the PH assumption.
COMPUTE LNtime_sex=LN(survtime)*sex. 
EXECUTE.

COXREG survtime
  /STATUS=status(1)
  /PATTERN BY sex
  /CONTRAST (sex)=Indicator(1)
  /METHOD=ENTER sex LNtime_sex 
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).

*6.3 Univariable Cox PH model.
COXREG survtime
  /STATUS=status(1)
  /PATTERN BY sex
  /CONTRAST (sex)=Indicator(1)
  /METHOD=ENTER sex 
  /PLOT LML
  /PRINT=CI(95)
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).

*6.4
*Recode string variables.

RECODE pt ('1'=1) ('2'=2) ('3'=3) ('4'=4) INTO T_stage.
VARIABLE LABELS  T_stage 'T_stage numeric'.
VALUE LABELS T_stage 1 'T1' 2 'T2' 3 'T3' 4 'T4'.
EXECUTE.

RECODE pn ('0'=0) ('1'=1) ('2'=1) ('X'=0) INTO Nodal_status.
VARIABLE LABELS  Nodal_status 'Nodal stage numeric'.
VALUE LABELS Nodal_status 0 'No nodal metastasis' 1 'Nodal metastasis'.
EXECUTE.

RECODE pm ('0'=0) ('1'=1) ('X'=0) INTO Distant_metastasis.
VARIABLE LABELS  Distant_metastasis 'Distant metastasis numeric'.
VALUE LABELS Distant_metastasis 0 'No distant metastasis' 1 'distant metastasis'.
EXECUTE.


*Check PH assumption for Nodal Status, Distant Metastasis and Breslow thickness.
COXREG survtime
  /STATUS=status(1)
  /PATTERN BY Nodal_status
  /CONTRAST (Nodal_status)=Indicator(1)
  /METHOD=ENTER Nodal_status 
  /PLOT LML
  /PRINT=CI(95)
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).

COXREG survtime
  /STATUS=status(1)
  /PATTERN BY Distant_metastasis
  /CONTRAST (Distant_metastasis)=Indicator(1)
  /METHOD=ENTER Distant_metastasis 
  /PLOT LML
  /PRINT=CI(95)
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).

COXREG survtime
  /STATUS=status(1)
  /PATTERN BY  T_stage 
  /CONTRAST (T_stage)=Indicator(1)
  /METHOD=ENTER T_stage
  /PLOT LML
  /PRINT=CI(95)
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).

*Perform the multivariable model.
COXREG survtime
  /STATUS=status(1)
  /CONTRAST (sex)=Indicator(1)
  /CONTRAST (Nodal_status)=Indicator(1)
  /CONTRAST (Distant_metastasis)=Indicator(1)
  /CONTRAST (T_stage)=Indicator(1)
  /METHOD=ENTER sex T_stage Nodal_status Distant_metastasis 
  /PRINT=CI(95)
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).

*6.5a.
*Cox PH regression with drug exposure a time-fixed covariate.
*Analyze > Survival > Cox Regression.
COXREG survtime
  /STATUS=status(1)
  /CONTRAST (Nodal_status)=Indicator(1)
  /CONTRAST (Distant_metastasis)=Indicator(1)
  /CONTRAST (BB_before_diagnosis)=Indicator(1)
  /CONTRAST (T_stage)=Indicator(1)
  /CONTRAST (sex)=Indicator(1)
  /METHOD=ENTER agedx sex T_stage Nodal_status Distant_metastasis BB_before_diagnosis 
  /PRINT=CI(95)
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).

*6.5b.
*Step 1. 
*Analyze > descriptive statistics > crosstabs.
CROSSTABS
  /TABLES=BB_start_after_diagnosis BY BB_before_diagnosis
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT
  /COUNT ROUND CELL.

*Step 2.
DO IF  MISSING(BB_start_after_diagnosis).
COMPUTE BB_time_var=1000000.
ELSE.
COMPUTE BB_time_var=BB_start_after_diagnosis.
END IF.
EXECUTE.

*Step3.
*Menu: Analyze > survival > Cox w/ Time Dep Cov...
TIME PROGRAM.
COMPUTE T_COV_ = T_>BB_time_var.
COXREG   survtime
  /STATUS=status(1)
  /CONTRAST (Nodal_status)=Indicator(1)
  /CONTRAST (sex)=Indicator(1)
  /CONTRAST (T_stage)=Indicator(1)
  /CONTRAST (Distant_metastasis)=Indicator(1)
  /METHOD=ENTER sex agedx T_stage Nodal_status Distant_metastasis T_COV_ 
  /PRINT=CI(95)
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).

*Extra question. 
*Does the PH assumption hold for the time-dependent covariate?
*Include a multiplication with LN(time).
TIME PROGRAM.
COMPUTE T_COV_ = (T_>BB_time_var)*LN(T_).
COXREG   survtime
  /STATUS=status(1)
  /CONTRAST (Nodal_status)=Indicator(1)
  /CONTRAST (sex)=Indicator(1)
  /CONTRAST (T_stage)=Indicator(1)
  /CONTRAST (Distant_metastasis)=Indicator(1)
  /METHOD=ENTER sex agedx T_stage Nodal_status Distant_metastasis T_COV_ 
  /PRINT=CI(95)
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20).
*the LNtime*time dependent covariate is nonsignificant p=0.17, thus the PH assumption holds. 
